@@ -1,22 +1,29 @@
 #! /bin/sh
-#
-# Copyright (C) 2016-2019 John W. Eaton
-#
-# This file is part of Octave.
-#
-# Octave is free software: you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# Octave is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with Octave; see the file COPYING.  If not, see
-# <https://www.gnu.org/licenses/>.
+
+########################################################################
+##
+## Copyright (C) 2016-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
+##
+## This file is part of Octave.
+##
+## Octave is free software: you can redistribute it and/or modify it
+## under the terms of the GNU General Public License as published by
+## the Free Software Foundation, either version 3 of the License, or
+## (at your option) any later version.
+##
+## Octave is distributed in the hope that it will be useful, but
+## WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+## GNU General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with Octave; see the file COPYING.  If not, see
+## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 : ${SED=@SED@}
 
@@ -26,10 +33,8 @@
 ##   OCTAVE_CONF_MKOCTFILE_AR
 ##   OCTAVE_CONF_MKOCTFILE_CC
 ##   OCTAVE_CONF_MKOCTFILE_CXX
-##   OCTAVE_CONF_MKOCTFILE_DL_LD
 ##   OCTAVE_CONF_MKOCTFILE_DL_LDFLAGS
 ##   OCTAVE_CONF_MKOCTFILE_F77
-##   OCTAVE_CONF_MKOCTFILE_LD_CXX
 ##   OCTAVE_CONF_MKOCTFILE_RANLIB
 
 canonical_host_type="@canonical_host_type@"
@@ -43,44 +48,64 @@ version="@PACKAGE_VERSION@"
 prefix="@prefix@"
 exec_prefix="@exec_prefix@"
 
-archlibdir=`echo "@archlibdir@" | sed "s|^${exec_prefix}/||"`
-bindir=`echo "@bindir@" | sed "s|^${exec_prefix}/||"`
-libdir=`echo "@libdir@" | sed "s|^${exec_prefix}/||"`
-libexecdir=`echo "@libexecdir@" | sed "s|^${exec_prefix}/||"`
-localapiarchlibdir=`echo "@localapiarchlibdir@" | sed "s|^${exec_prefix}/||"`
-localapioctfiledir=`echo "@localapioctfiledir@" | sed "s|^${exec_prefix}/||"`
-localarchlibdir=`echo "@localarchlibdir@" | sed "s|^${exec_prefix}/||"`
-localoctfiledir=`echo "@localoctfiledir@" | sed "s|^${exec_prefix}/||"`
-localverarchlibdir=`echo "@localverarchlibdir@" | sed "s|^${exec_prefix}/||"`
-localveroctfiledir=`echo "@localveroctfiledir@" | sed "s|^${exec_prefix}/||"`
-octfiledir=`echo "@octfiledir@" | sed "s|^${exec_prefix}/||"`
-octlibdir=`echo "@octlibdir@" | sed "s|^${exec_prefix}/||"`
+archlibdir=`echo "@archlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+bindir=`echo "@bindir@" | $SED "s|^${exec_prefix}/\\+||"`
+libdir=`echo "@libdir@" | $SED "s|^${exec_prefix}/\\+||"`
+libexecdir=`echo "@libexecdir@" | $SED "s|^${exec_prefix}/\\+||"`
+localapiarchlibdir=`echo "@localapiarchlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+localapioctfiledir=`echo "@localapioctfiledir@" | $SED "s|^${exec_prefix}/\\+||"`
+localarchlibdir=`echo "@localarchlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+localoctfiledir=`echo "@localoctfiledir@" | $SED "s|^${exec_prefix}/\\+||"`
+localverarchlibdir=`echo "@localverarchlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+localveroctfiledir=`echo "@localveroctfiledir@" | $SED "s|^${exec_prefix}/\\+||"`
+octfiledir=`echo "@octfiledir@" | $SED "s|^${exec_prefix}/\\+||"`
+octlibdir=`echo "@octlibdir@" | $SED "s|^${exec_prefix}/\\+||"`
+
+datadir=`echo "@datadir@" | $SED "s|^${prefix}/\\+||"`
+datarootdir=`echo "@datarootdir@" | $SED "s|^${prefix}/\\+||"`
+doc_cache_file=`echo "@doc_cache_file@" | $SED "s|^${prefix}/\\+||"`
+exec_prefix=`echo "@exec_prefix@" | $SED "s|^${prefix}/\\+||"`
+fcnfiledir=`echo "@fcnfiledir@" | $SED "s|^${prefix}/\\+||"`
+imagedir=`echo "@imagedir@" | $SED "s|^${prefix}/\\+||"`
+includedir=`echo "@includedir@" | $SED "s|^${prefix}/\\+||"`
+infodir=`echo "@infodir@" | $SED "s|^${prefix}/\\+||"`
+infofile=`echo "@infofile@" | $SED "s|^${prefix}/\\+||"`
+localapifcnfiledir=`echo "@localapifcnfiledir@" | $SED "s|^${prefix}/\\+||"`
+localfcnfiledir=`echo "@localfcnfiledir@" | $SED "s|^${prefix}/\\+||"`
+localstartupfiledir=`echo "@localstartupfiledir@" | $SED "s|^${prefix}/\\+||"`
+localapiarchlibdir=`echo "@localapiarchlibdir@" | $SED "s|^${prefix}/\\+||"`
+localverfcnfiledir=`echo "@localverfcnfiledir@" | $SED "s|^${prefix}/\\+||"`
+man1dir=`echo "@man1dir@" | $SED "s|^${prefix}/\\+||"`
+mandir=`echo "@mandir@" | $SED "s|^${prefix}/\\+||"`
+octdatadir=`echo "@octdatadir@" | $SED "s|^${prefix}/\\+||"`
+octdocdir=`echo "@octdocdir@" | $SED "s|^${prefix}/\\+||"`
+octetcdir=`echo "@octetcdir@" | $SED "s|^${prefix}/\\+||"`
+octfontsdir=`echo "@octfontsdir@" | $SED "s|^${prefix}/\\+||"`
+octincludedir=`echo "@octincludedir@" | $SED "s|^${prefix}/\\+||"`
+octlocaledir=`echo "@octlocaledir@" | $SED "s|^${prefix}/\\+||"`
+octtestsdir=`echo "@octtestsdir@" | $SED "s|^${prefix}/\\+||"`
+startupfiledir=`echo "@startupfiledir@" | $SED "s|^${prefix}/\\+||"`
+texi_macros_file=`echo "@texi_macros_file@" | $SED "s|^${prefix}/\\+||"`
+
+## FIXME: Some of these flags might contain double quotes.
+##        Is it ok to use single quotes here?
+if [ "x@OCTAVE_RELOCATE_ALL@" = "xyes" ]; then
+  ## Replace portions of compiler flags that depend on prefix on target
+  cppflags=`echo '@CPPFLAGS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  fftw3f_ldflags=`echo '@FFTW3F_LDFLAGS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  fftw3_ldflags=`echo '@FFTW3_LDFLAGS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  flibs=`echo '@FLIBS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  ldflags=`echo '@LDFLAGS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+  oct_link_opts=`echo '@OCT_LINK_OPTS@' | $SED "s|@prefix@|\$\{prefix\}|g" | $SED 's|\"|\\\\\\\"|g'`
+else
+  cppflags=`echo '@CPPFLAGS@' | $SED 's|\"|\\\\\\\"|g'`
+  fftw3f_ldflags=`echo '@FFTW3F_LDFLAGS@' | $SED 's|\"|\\\\\\\"|g'`
+  fftw3_ldflags=`echo '@FFTW3_LDFLAGS@' | $SED 's|\"|\\\\\\\"|g'`
+  flibs=`echo '@FLIBS@' | $SED 's|\"|\\\\\\\"|g'`
+  ldflags=`echo '@LDFLAGS@' | $SED 's|\"|\\\\\\\"|g'`
+  oct_link_opts=`echo '@OCT_LINK_OPTS@' | $SED 's|\"|\\\\\\\"|g'`
+fi
 
-datadir=`echo "@datadir@" | sed "s|^${prefix}/||"`
-datarootdir=`echo "@datarootdir@" | sed "s|^${prefix}/||"`
-doc_cache_file=`echo "@doc_cache_file@" | sed "s|^${prefix}/||"`
-exec_prefix=`echo "@exec_prefix@" | sed "s|^${prefix}/||"`
-fcnfiledir=`echo "@fcnfiledir@" | sed "s|^${prefix}/||"`
-imagedir=`echo "@imagedir@" | sed "s|^${prefix}/||"`
-includedir=`echo "@includedir@" | sed "s|^${prefix}/||"`
-infodir=`echo "@infodir@" | sed "s|^${prefix}/||"`
-infofile=`echo "@infofile@" | sed "s|^${prefix}/||"`
-localapifcnfiledir=`echo "@localapifcnfiledir@" | sed "s|^${prefix}/||"`
-localfcnfiledir=`echo "@localfcnfiledir@" | sed "s|^${prefix}/||"`
-localstartupfiledir=`echo "@localstartupfiledir@" | sed "s|^${prefix}/||"`
-localapiarchlibdir=`echo "@localapiarchlibdir@" | sed "s|^${prefix}/||"`
-localverfcnfiledir=`echo "@localverfcnfiledir@" | sed "s|^${prefix}/||"`
-man1dir=`echo "@man1dir@" | sed "s|^${prefix}/||"`
-mandir=`echo "@mandir@" | sed "s|^${prefix}/||"`
-octdatadir=`echo "@octdatadir@" | sed "s|^${prefix}/||"`
-octdocdir=`echo "@octdocdir@" | sed "s|^${prefix}/||"`
-octetcdir=`echo "@octetcdir@" | sed "s|^${prefix}/||"`
-octfontsdir=`echo "@octfontsdir@" | sed "s|^${prefix}/||"`
-octincludedir=`echo "@octincludedir@" | sed "s|^${prefix}/||"`
-octlocaledir=`echo "@octlocaledir@" | sed "s|^${prefix}/||"`
-octtestsdir=`echo "@octtestsdir@" | sed "s|^${prefix}/||"`
-startupfiledir=`echo "@startupfiledir@" | sed "s|^${prefix}/||"`
-texi_macros_file=`echo "@texi_macros_file@" | sed "s|^${prefix}/||"`
 
 srcdir="@srcdir@"
 top_srcdir="@top_srcdir@"
@@ -113,7 +138,6 @@ COLAMD_CPPFLAGS="@COLAMD_CPPFLAGS@"
 COLAMD_LDFLAGS="@COLAMD_LDFLAGS@"
 COLAMD_LIBS="@COLAMD_LIBS@"
 CPICFLAG="@CPICFLAG@"
-CPPFLAGS="@CPPFLAGS@"
 CURL_CPPFLAGS="@CURL_CPPFLAGS@"
 CURL_LDFLAGS="@CURL_LDFLAGS@"
 CURL_LIBS="@CURL_LIBS@"
@@ -128,7 +152,6 @@ DEFAULT_PAGER="@DEFAULT_PAGER@"
 DEFS="@DEFS@"
 DEPEND_FLAGS="@DEPEND_FLAGS@"
 DEPEND_EXTRA_SED_PATTERN="@DEPEND_EXTRA_SED_PATTERN@"
-DL_LD="@DL_LD@"
 DL_LDFLAGS="@DL_LDFLAGS@"
 EXEEXT="@EXEEXT@"
 GCC_VERSION="@GCC_VERSION@"
@@ -138,12 +161,9 @@ F77_FLOAT_STORE_FLAG="@F77_FLOAT_STORE_FLAG@"
 F77_INTEGER_8_FLAG="@F77_INTEGER_8_FLAG@"
 FFLAGS="@FFLAGS@"
 FFTW3_CPPFLAGS="@FFTW3_CPPFLAGS@"
-FFTW3_LDFLAGS="@FFTW3_LDFLAGS@"
 FFTW3_LIBS="@FFTW3_LIBS@"
 FFTW3F_CPPFLAGS="@FFTW3F_CPPFLAGS@"
-FFTW3F_LDFLAGS="@FFTW3F_LDFLAGS@"
 FFTW3F_LIBS="@FFTW3F_LIBS@"
-FLIBS="@FLIBS@"
 FLTK_CPPFLAGS="@FLTK_CPPFLAGS@"
 FLTK_LDFLAGS="@FLTK_LDFLAGS@"
 FLTK_LIBS="@FLTK_LIBS@"
@@ -163,8 +183,6 @@ KLU_CPPFLAGS="@KLU_CPPFLAGS@"
 KLU_LDFLAGS="@KLU_LDFLAGS@"
 KLU_LIBS="@KLU_LIBS@"
 LAPACK_LIBS="@LAPACK_LIBS@"
-LD_CXX="@LD_CXX@"
-LDFLAGS="@LDFLAGS@"
 LD_STATIC_FLAG="@LD_STATIC_FLAG@"
 LEX="@LEX@"
 LEXLIB="@LEXLIB@"
@@ -172,9 +190,6 @@ LFLAGS="@LFLAGS@"
 LIBOCTAVE="@LIBOCTAVE@"
 LIBOCTINTERP="@LIBOCTINTERP@"
 LIBS="@LIBS@"
-LLVM_CPPFLAGS="@LLVM_CPPFLAGS@"
-LLVM_LDFLAGS="@LLVM_LDFLAGS@"
-LLVM_LIBS="@LLVM_LIBS@"
 LN_S="@LN_S@"
 MAGICK_CPPFLAGS="@MAGICK_CPPFLAGS@"
 MAGICK_LDFLAGS="@MAGICK_LDFLAGS@"
@@ -184,7 +199,6 @@ MKOCTFILE_OCT_LINK_DEPS="@MKOCTFILE_OCT_LINK_DEPS@"
 OCTAVE_LINK_DEPS="@OCTAVE_LINK_DEPS@"
 OCTAVE_LINK_OPTS="@OCTAVE_LINK_OPTS@"
 OCT_LINK_DEPS="@OCT_LINK_DEPS@"
-OCT_LINK_OPTS="@OCT_LINK_OPTS@"
 OPENGL_LIBS="@OPENGL_LIBS@"
 PCRE_CPPFLAGS="@PCRE_CPPFLAGS@"
 PCRE_LDFLAGS="@PCRE_LDFLAGS@"
@@ -203,9 +217,8 @@ QT_LIBS="@QT_LIBS@"
 QT_OPENGL_LIBS="@QT_OPENGL_LIBS@"
 RANLIB="@RANLIB@"
 RDYNAMIC_FLAG="@RDYNAMIC_FLAG@"
-READLINE_LIBS="@READLINE_LIBS@"
+READLINE_LIBS="@LIBREADLINE@"
 SHARED_LIBS="@SHARED_LIBS@"
-SH_LD="@SH_LD@"
 SH_LDFLAGS="@SH_LDFLAGS@"
 STATIC_LIBS="@STATIC_LIBS@"
 SUITESPARSECONFIG_LIBS="@SUITESPARSECONFIG_LIBS@"
@@ -215,7 +228,9 @@ SUNDIALS_IDA_LIBS="@SUNDIALS_IDA_LIBS@"
 SUNDIALS_NVECSERIAL_CPPFLAGS="@SUNDIALS_NVECSERIAL_CPPFLAGS@"
 SUNDIALS_NVECSERIAL_LDFLAGS="@SUNDIALS_NVECSERIAL_LDFLAGS@"
 SUNDIALS_NVECSERIAL_LIBS="@SUNDIALS_NVECSERIAL_LIBS@"
-TERM_LIBS="@TERM_LIBS@"
+SUNDIALS_SUNLINSOLKLU_CPPFLAGS="@SUNDIALS_SUNLINSOLKLU_CPPFLAGS@"
+SUNDIALS_SUNLINSOLKLU_LDFLAGS="@SUNDIALS_SUNLINSOLKLU_LDFLAGS@"
+SUNDIALS_SUNLINSOLKLU_LIBS="@SUNDIALS_SUNLINSOLKLU_LIBS@"
 UMFPACK_CPPFLAGS="@UMFPACK_CPPFLAGS@"
 UMFPACK_LDFLAGS="@UMFPACK_LDFLAGS@"
 UMFPACK_LIBS="@UMFPACK_LIBS@"
@@ -266,7 +281,7 @@ $SED \
   -e "s|%OCTAVE_CONF_COLAMD_LDFLAGS%|\"${COLAMD_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_COLAMD_LIBS%|\"${COLAMD_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_CPICFLAG%|\"${CPICFLAG}\"|" \
-  -e "s|%OCTAVE_CONF_CPPFLAGS%|\"${CPPFLAGS}\"|" \
+  -e "s|%OCTAVE_CONF_CPPFLAGS%|\"${cppflags}\"|" \
   -e "s|%OCTAVE_CONF_CURL_CPPFLAGS%|\"${CURL_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_CURL_LDFLAGS%|\"${CURL_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_CURL_LIBS%|\"${CURL_LIBS}\"|" \
@@ -281,7 +296,6 @@ $SED \
   -e "s|%OCTAVE_CONF_DEFS%|\"${DEFS}\"|" \
   -e "s|%OCTAVE_CONF_DEPEND_EXTRA_SED_PATTERN%|\"${DEPEND_EXTRA_SED_PATTERN}\"|" \
   -e "s|%OCTAVE_CONF_DEPEND_FLAGS%|\"${DEPEND_FLAGS}\"|" \
-  -e "s|%OCTAVE_CONF_DL_LD%|\"${DL_LD}\"|" \
   -e "s|%OCTAVE_CONF_DL_LDFLAGS%|\"${DL_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_EXEC_PREFIX%|\"${exec_prefix}\"|" \
   -e "s|%OCTAVE_CONF_EXEEXT%|\"${EXEEXT}\"|" \
@@ -290,12 +304,12 @@ $SED \
   -e "s|%OCTAVE_CONF_F77_INTEGER_8_FLAG%|\"${F77_INTEGER_8_FLAG}\"|" \
   -e "s|%OCTAVE_CONF_FFLAGS%|\"${FFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_FFTW3F_CPPFLAGS%|\"${FFTW3F_CPPFLAGS}\"|" \
-  -e "s|%OCTAVE_CONF_FFTW3F_LDFLAGS%|\"${FFTW3F_LDFLAGS}\"|" \
+  -e "s|%OCTAVE_CONF_FFTW3F_LDFLAGS%|\"${fftw3f_ldflags}\"|" \
   -e "s|%OCTAVE_CONF_FFTW3F_LIBS%|\"${FFTW3F_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_FFTW3_CPPFLAGS%|\"${FFTW3_CPPFLAGS}\"|" \
-  -e "s|%OCTAVE_CONF_FFTW3_LDFLAGS%|\"${FFTW3_LDFLAGS}\"|" \
+  -e "s|%OCTAVE_CONF_FFTW3_LDFLAGS%|\"${fftw3_ldflags}\"|" \
   -e "s|%OCTAVE_CONF_FFTW3_LIBS%|\"${FFTW3_LIBS}\"|" \
-  -e "s|%OCTAVE_CONF_FLIBS%|\"${FLIBS}\"|" \
+  -e "s|%OCTAVE_CONF_FLIBS%|\"${flibs}\"|" \
   -e "s|%OCTAVE_CONF_FLTK_CPPFLAGS%|\"${FLTK_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_FLTK_LDFLAGS%|\"${FLTK_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_FLTK_LIBS%|\"${FLTK_LIBS}\"|" \
@@ -319,8 +333,7 @@ $SED \
   -e "s|%OCTAVE_CONF_KLU_LDFLAGS%|\"${KLU_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_KLU_LIBS%|\"${KLU_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_LAPACK_LIBS%|\"${LAPACK_LIBS}\"|" \
-  -e "s|%OCTAVE_CONF_LDFLAGS%|\"${LDFLAGS}\"|" \
-  -e "s|%OCTAVE_CONF_LD_CXX%|\"${LD_CXX}\"|" \
+  -e "s|%OCTAVE_CONF_LDFLAGS%|\"${ldflags}\"|" \
   -e "s|%OCTAVE_CONF_LD_STATIC_FLAG%|\"${LD_STATIC_FLAG}\"|" \
   -e "s|%OCTAVE_CONF_LEX%|\"${LEX}\"|" \
   -e "s|%OCTAVE_CONF_LEXLIB%|\"${LEXLIB}\"|" \
@@ -329,9 +342,6 @@ $SED \
   -e "s|%OCTAVE_CONF_LIBOCTAVE%|\"${LIBOCTAVE}\"|" \
   -e "s|%OCTAVE_CONF_LIBOCTINTERP%|\"${LIBOCTINTERP}\"|" \
   -e "s|%OCTAVE_CONF_LIBS%|\"${LIBS}\"|" \
-  -e "s|%OCTAVE_CONF_LLVM_CPPFLAGS%|\"${LLVM_CPPFLAGS}\"|" \
-  -e "s|%OCTAVE_CONF_LLVM_LDFLAGS%|\"${LLVM_LDFLAGS}\"|" \
-  -e "s|%OCTAVE_CONF_LLVM_LIBS%|\"${LLVM_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_LN_S%|\"${LN_S}\"|" \
   -e "s|%OCTAVE_CONF_MAGICK_CPPFLAGS%|\"${MAGICK_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_MAGICK_LDFLAGS%|\"${MAGICK_LDFLAGS}\"|" \
@@ -339,10 +349,8 @@ $SED \
   -e "s|%OCTAVE_CONF_MKOCTFILE_AR%|\"${AR}\"|" \
   -e "s|%OCTAVE_CONF_MKOCTFILE_CC%|\"${CC}\"|" \
   -e "s|%OCTAVE_CONF_MKOCTFILE_CXX%|\"${CXX}\"|" \
-  -e "s|%OCTAVE_CONF_MKOCTFILE_DL_LD%|\"${DL_LD}\"|" \
   -e "s|%OCTAVE_CONF_MKOCTFILE_DL_LDFLAGS%|\"${DL_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_MKOCTFILE_F77%|\"${F77}\"|" \
-  -e "s|%OCTAVE_CONF_MKOCTFILE_LD_CXX%|\"${LD_CXX}\"|" \
   -e "s|%OCTAVE_CONF_MKOCTFILE_OCTAVE_LINK_DEPS%|\"${MKOCTFILE_OCTAVE_LINK_DEPS}\"|" \
   -e "s|%OCTAVE_CONF_MKOCTFILE_OCT_LINK_DEPS%|\"${MKOCTFILE_OCT_LINK_DEPS}\"|" \
   -e "s|%OCTAVE_CONF_MKOCTFILE_RANLIB%|\"${RANLIB}\"|" \
@@ -351,7 +359,7 @@ $SED \
   -e "s|%OCTAVE_CONF_OCTINCLUDEDIR%|\"${octincludedir}\"|" \
   -e "s|%OCTAVE_CONF_OCTLIBDIR%|\"${octlibdir}\"|" \
   -e "s|%OCTAVE_CONF_OCT_LINK_DEPS%|\"${OCT_LINK_DEPS}\"|" \
-  -e "s|%OCTAVE_CONF_OCT_LINK_OPTS%|\"${OCT_LINK_OPTS}\"|" \
+  -e "s|%OCTAVE_CONF_OCT_LINK_OPTS%|\"${oct_link_opts}\"|" \
   -e "s|%OCTAVE_CONF_OPENGL_LIBS%|\"${OPENGL_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_PCRE_CPPFLAGS%|\"${PCRE_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_PCRE_LDFLAGS%|\"${PCRE_LDFLAGS}\"|" \
@@ -374,7 +382,6 @@ $SED \
   -e "s|%OCTAVE_CONF_READLINE_LIBS%|\"${READLINE_LIBS}\"|" | \
   $SED \
   -e "s|%OCTAVE_CONF_SHARED_LIBS%|\"${SHARED_LIBS}\"|" \
-  -e "s|%OCTAVE_CONF_SH_LD%|\"${SH_LD}\"|" \
   -e "s|%OCTAVE_CONF_SH_LDFLAGS%|\"${SH_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_STATIC_LIBS%|\"${STATIC_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_SUITESPARSECONFIG_LIBS%|\"${SUITESPARSECONFIG_LIBS}\"|" \
@@ -384,7 +391,9 @@ $SED \
   -e "s|%OCTAVE_CONF_SUNDIALS_NVECSERIAL_CPPFLAGS%|\"${SUNDIALS_NVECSERIAL_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_SUNDIALS_NVECSERIAL_LDFLAGS%|\"${SUNDIALS_NVECSERIAL_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_SUNDIALS_NVECSERIAL_LIBS%|\"${SUNDIALS_NVECSERIAL_LIBS}\"|" \
-  -e "s|%OCTAVE_CONF_TERM_LIBS%|\"${TERM_LIBS}\"|" \
+  -e "s|%OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_CPPFLAGS%|\"${SUNDIALS_SUNLINSOLKLU_CPPFLAGS}\"|" \
+  -e "s|%OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_LDFLAGS%|\"${SUNDIALS_SUNLINSOLKLU_LDFLAGS}\"|" \
+  -e "s|%OCTAVE_CONF_SUNDIALS_SUNLINSOLKLU_LIBS%|\"${SUNDIALS_SUNLINSOLKLU_LIBS}\"|" \
   -e "s|%OCTAVE_CONF_UMFPACK_CPPFLAGS%|\"${UMFPACK_CPPFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_UMFPACK_LDFLAGS%|\"${UMFPACK_LDFLAGS}\"|" \
   -e "s|%OCTAVE_CONF_UMFPACK_LIBS%|\"${UMFPACK_LIBS}\"|" \
