@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1995-2022 The Octave Project Developers
+// Copyright (C) 1995-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -54,7 +54,6 @@
 #include "defaults.h"
 #include "defun.h"
 #include "error.h"
-#include "file-io.h"
 #include "help.h"
 #include "interpreter-private.h"
 #include "octave.h"
@@ -72,7 +71,7 @@
 #  define SHELL_PATH "/bin/sh"
 #endif
 
-OCTAVE_NAMESPACE_BEGIN
+OCTAVE_BEGIN_NAMESPACE(octave)
 
 #define STRINGIFY(s) STRINGIFY1(s)
 #define STRINGIFY1(s) #s
@@ -114,8 +113,7 @@ run_command_and_return_output (const std::string& cmd_str)
   iprocstream *cmd = new iprocstream (cmd_str.c_str ());
   frame.add_delete (cmd);
 
-  child_list& kids
-    = __get_child_list__ ("run_command_and_return_output");
+  child_list& kids = __get_child_list__ ();
   frame.add (&child_list::remove, kids, cmd->pid ());
 
   if (! *cmd)
@@ -287,7 +285,7 @@ Windows systems.
 #endif
 
   unwind_action restore_mask
-    ([] (void *mask) { restore_signal_mask (mask); }, get_signal_mask ());
+  ([] (void *mask) { restore_signal_mask (mask); }, get_signal_mask ());
 
   octave_unblock_async_signals ();
   octave_unblock_signal_by_name ("SIGTSTP");
@@ -342,8 +340,8 @@ find_config_info (const octave_scalar_map& m, const std::string& key)
 
 DEFUN (__octave_config_info__, args, ,
        doc: /* -*- texinfo -*-
-@deftypefn  {} {} __octave_config_info__ ()
-@deftypefnx {} {} __octave_config_info__ (@var{option})
+@deftypefn  {} {@var{S} =} __octave_config_info__ ()
+@deftypefnx {} {@var{S} =} __octave_config_info__ (@var{option})
 Return a structure containing configuration and installation information for
 Octave.
 
@@ -362,209 +360,210 @@ specified option.
   if (! initialized)
     {
       std::map<std::string, octave_value> conf_info_map
-        = {{ "DEFAULT_PAGER", config::default_pager () },
+      = {{ "DEFAULT_PAGER", config::default_pager () },
 
 #if defined (OCTAVE_ENABLE_64)
-           { "ENABLE_64", true },
+        { "ENABLE_64", true },
 #else
-           { "ENABLE_64", false },
+        { "ENABLE_64", false },
 #endif
 
 #if defined (OCTAVE_ENABLE_COMMAND_LINE_PUSH_PARSER)
-           { "ENABLE_COMMAND_LINE_PUSH_PARSER", true },
+        { "ENABLE_COMMAND_LINE_PUSH_PARSER", true },
 #else
-           { "ENABLE_COMMAND_LINE_PUSH_PARSER", false },
+        { "ENABLE_COMMAND_LINE_PUSH_PARSER", false },
 #endif
 
 #if defined (ENABLE_DOCS)
-           { "ENABLE_DOCS", true },
+        { "ENABLE_DOCS", true },
 #else
-           { "ENABLE_DOCS", false },
+        { "ENABLE_DOCS", false },
 #endif
 
 #if defined (OCTAVE_ENABLE_FLOAT_TRUNCATE)
-           { "ENABLE_FLOAT_TRUNCATE", true },
+        { "ENABLE_FLOAT_TRUNCATE", true },
 #else
-           { "ENABLE_FLOAT_TRUNCATE", false },
+        { "ENABLE_FLOAT_TRUNCATE", false },
 #endif
 
 #if defined (OCTAVE_ENABLE_OPENMP)
-           { "ENABLE_OPENMP", true },
+        { "ENABLE_OPENMP", true },
 #else
-           { "ENABLE_OPENMP", false },
+        { "ENABLE_OPENMP", false },
 #endif
 
-           { "api_version", OCTAVE_API_VERSION },
-           { "archlibdir", config::arch_lib_dir () },
-           { "bindir", config::bin_dir () },
-           { "canonical_host_type", config::canonical_host_type () },
-           { "datadir", config::data_dir () },
-           { "datarootdir", config::dataroot_dir () },
-           { "fcnfiledir", config::fcn_file_dir () },
-           { "fftw_version", fftw_version () },
-           { "fftwf_version", fftwf_version () },
-           { "imagedir", config::image_dir () },
-           { "includedir", config::include_dir () },
-           { "infodir", config::info_dir () },
-           { "libdir", config::lib_dir () },
-           { "libexecdir", config::libexec_dir () },
-           // Each library and executable has its own definition of the hg
-           // id.  We check for consistency when Octave starts so we just
-           // store and report one of them here.
-           { "hg_id", liboctinterp_hg_id () },
-           { "localapiarchlibdir", config::local_api_arch_lib_dir () },
-           { "localapifcnfiledir", config::local_api_fcn_file_dir () },
-           { "localapioctfiledir", config::local_api_oct_file_dir () },
-           { "localarchlibdir", config::local_arch_lib_dir () },
-           { "localfcnfiledir", config::local_fcn_file_dir () },
-           { "localoctfiledir", config::local_oct_file_dir () },
-           { "localstartupfiledir", config::local_startupfile_dir () },
-           { "localverarchlibdir", config::local_ver_arch_lib_dir () },
-           { "localverfcnfiledir", config::local_ver_fcn_file_dir () },
-           { "localveroctfiledir", config::local_ver_oct_file_dir () },
-           { "major_version", STRINGIFY (OCTAVE_MAJOR_VERSION) },
-           { "man1dir", config::man1_dir () },
-           { "man1ext", config::man1_ext () },
-           { "mandir", config::man_dir () },
-           { "minor_version", STRINGIFY (OCTAVE_MINOR_VERSION) },
-           { "octdatadir", config::oct_data_dir () },
-           { "octdocdir", config::oct_doc_dir () },
-           { "octetcdir", config::oct_etc_dir () },
-           { "octfiledir", config::oct_file_dir () },
-           { "octfontsdir", config::oct_fonts_dir () },
-           { "octincludedir", config::oct_include_dir () },
-           { "octlibdir", config::oct_lib_dir () },
-           { "octtestsdir", config::oct_tests_dir () },
-           { "patch_version", STRINGIFY (OCTAVE_PATCH_VERSION) },
-           { "release_date", OCTAVE_RELEASE_DATE },
-           { "startupfiledir", config::startupfile_dir () },
-           { "version", OCTAVE_VERSION }};
+        { "api_version", OCTAVE_API_VERSION },
+        { "archlibdir", config::arch_lib_dir () },
+        { "bindir", config::bin_dir () },
+        { "canonical_host_type", config::canonical_host_type () },
+        { "datadir", config::data_dir () },
+        { "datarootdir", config::dataroot_dir () },
+        { "fcnfiledir", config::fcn_file_dir () },
+        { "fftw_version", fftw_version () },
+        { "fftwf_version", fftwf_version () },
+        { "imagedir", config::image_dir () },
+        { "includedir", config::include_dir () },
+        { "infodir", config::info_dir () },
+        { "libdir", config::lib_dir () },
+        { "libexecdir", config::libexec_dir () },
+        // Each library and executable has its own definition of the hg
+        // id.  We check for consistency when Octave starts so we just
+        // store and report one of them here.
+        { "hg_id", liboctinterp_hg_id () },
+        { "localapiarchlibdir", config::local_api_arch_lib_dir () },
+        { "localapifcnfiledir", config::local_api_fcn_file_dir () },
+        { "localapioctfiledir", config::local_api_oct_file_dir () },
+        { "localarchlibdir", config::local_arch_lib_dir () },
+        { "localfcnfiledir", config::local_fcn_file_dir () },
+        { "localoctfiledir", config::local_oct_file_dir () },
+        { "localstartupfiledir", config::local_startupfile_dir () },
+        { "localverarchlibdir", config::local_ver_arch_lib_dir () },
+        { "localverfcnfiledir", config::local_ver_fcn_file_dir () },
+        { "localveroctfiledir", config::local_ver_oct_file_dir () },
+        { "major_version", STRINGIFY (OCTAVE_MAJOR_VERSION) },
+        { "man1dir", config::man1_dir () },
+        { "man1ext", config::man1_ext () },
+        { "mandir", config::man_dir () },
+        { "minor_version", STRINGIFY (OCTAVE_MINOR_VERSION) },
+        { "octdatadir", config::oct_data_dir () },
+        { "octdocdir", config::oct_doc_dir () },
+        { "octetcdir", config::oct_etc_dir () },
+        { "octfiledir", config::oct_file_dir () },
+        { "octfontsdir", config::oct_fonts_dir () },
+        { "octincludedir", config::oct_include_dir () },
+        { "octlibdir", config::oct_lib_dir () },
+        { "octtestsdir", config::oct_tests_dir () },
+        { "patch_version", STRINGIFY (OCTAVE_PATCH_VERSION) },
+        { "release_date", OCTAVE_RELEASE_DATE },
+        { "startupfiledir", config::startupfile_dir () },
+        { "version", OCTAVE_VERSION }
+      };
 
       std::map<std::string, octave_value> build_env_map
-        = {{ "AMD_CPPFLAGS", build_env::AMD_CPPFLAGS },
-           { "AMD_LDFLAGS", build_env::AMD_LDFLAGS },
-           { "AMD_LIBS", build_env::AMD_LIBS },
-           { "AR", build_env::AR },
-           { "ARFLAGS", build_env::ARFLAGS },
-           { "ARPACK_CPPFLAGS", build_env::ARPACK_CPPFLAGS },
-           { "ARPACK_LDFLAGS", build_env::ARPACK_LDFLAGS },
-           { "ARPACK_LIBS", build_env::ARPACK_LIBS },
-           { "BLAS_LIBS", build_env::BLAS_LIBS },
-           { "CAMD_CPPFLAGS", build_env::CAMD_CPPFLAGS },
-           { "CAMD_LDFLAGS", build_env::CAMD_LDFLAGS },
-           { "CAMD_LIBS", build_env::CAMD_LIBS },
-           { "CARBON_LIBS", build_env::CARBON_LIBS },
-           { "CC", build_env::CC },
-           { "CCOLAMD_CPPFLAGS", build_env::CCOLAMD_CPPFLAGS },
-           { "CCOLAMD_LDFLAGS", build_env::CCOLAMD_LDFLAGS },
-           { "CCOLAMD_LIBS", build_env::CCOLAMD_LIBS },
-           { "CFLAGS", build_env::CFLAGS },
-           { "CHOLMOD_CPPFLAGS", build_env::CHOLMOD_CPPFLAGS },
-           { "CHOLMOD_LDFLAGS", build_env::CHOLMOD_LDFLAGS },
-           { "CHOLMOD_LIBS", build_env::CHOLMOD_LIBS },
-           { "COLAMD_CPPFLAGS", build_env::COLAMD_CPPFLAGS },
-           { "COLAMD_LDFLAGS", build_env::COLAMD_LDFLAGS },
-           { "COLAMD_LIBS", build_env::COLAMD_LIBS },
-           { "CPICFLAG", build_env::CPICFLAG },
-           { "CPPFLAGS", build_env::CPPFLAGS },
-           { "CURL_CPPFLAGS", build_env::CURL_CPPFLAGS },
-           { "CURL_LDFLAGS", build_env::CURL_LDFLAGS },
-           { "CURL_LIBS", build_env::CURL_LIBS },
-           { "CXSPARSE_CPPFLAGS", build_env::CXSPARSE_CPPFLAGS },
-           { "CXSPARSE_LDFLAGS", build_env::CXSPARSE_LDFLAGS },
-           { "CXSPARSE_LIBS", build_env::CXSPARSE_LIBS },
-           { "CXX", build_env::CXX },
-           { "CXXCPP", build_env::CXXCPP },
-           { "CXXFLAGS", build_env::CXXFLAGS },
-           { "CXXPICFLAG", build_env::CXXPICFLAG },
-           { "DEFS", build_env::DEFS },
-           { "DL_LDFLAGS", build_env::DL_LDFLAGS },
-           { "GCC_VERSION", build_env::GCC_VERSION },
-           { "GXX_VERSION", build_env::GXX_VERSION },
-           { "EXEEXT", build_env::EXEEXT },
-           { "F77", build_env::F77 },
-           { "F77_FLOAT_STORE_FLAG", build_env::F77_FLOAT_STORE_FLAG },
-           { "F77_INTEGER_8_FLAG", build_env::F77_INTEGER_8_FLAG },
-           { "FFLAGS", build_env::FFLAGS },
-           { "FFTW3_CPPFLAGS", build_env::FFTW3_CPPFLAGS },
-           { "FFTW3_LDFLAGS", build_env::FFTW3_LDFLAGS },
-           { "FFTW3_LIBS", build_env::FFTW3_LIBS },
-           { "FFTW3F_CPPFLAGS", build_env::FFTW3F_CPPFLAGS },
-           { "FFTW3F_LDFLAGS", build_env::FFTW3F_LDFLAGS },
-           { "FFTW3F_LIBS", build_env::FFTW3F_LIBS },
-           { "FLIBS", build_env::FLIBS },
-           { "FLTK_CPPFLAGS", build_env::FLTK_CPPFLAGS },
-           { "FLTK_LDFLAGS", build_env::FLTK_LDFLAGS },
-           { "FLTK_LIBS", build_env::FLTK_LIBS },
-           { "FONTCONFIG_CPPFLAGS", build_env::FONTCONFIG_CPPFLAGS },
-           { "FONTCONFIG_LIBS", build_env::FONTCONFIG_LIBS },
-           { "FPICFLAG", build_env::FPICFLAG },
-           { "FT2_CPPFLAGS", build_env::FT2_CPPFLAGS },
-           { "FT2_LIBS", build_env::FT2_LIBS },
-           { "GLPK_CPPFLAGS", build_env::GLPK_CPPFLAGS },
-           { "GLPK_LDFLAGS", build_env::GLPK_LDFLAGS },
-           { "GLPK_LIBS", build_env::GLPK_LIBS },
-           { "GNUPLOT", build_env::GNUPLOT },
-           { "HDF5_CPPFLAGS", build_env::HDF5_CPPFLAGS },
-           { "HDF5_LDFLAGS", build_env::HDF5_LDFLAGS },
-           { "HDF5_LIBS", build_env::HDF5_LIBS },
-           { "LAPACK_LIBS", build_env::LAPACK_LIBS },
-           { "LDFLAGS", build_env::LDFLAGS },
-           { "LD_STATIC_FLAG", build_env::LD_STATIC_FLAG },
-           { "LEX", build_env::LEX },
-           { "LEXLIB", build_env::LEXLIB },
-           { "LFLAGS", build_env::LFLAGS },
-           { "LIBOCTAVE", build_env::LIBOCTAVE },
-           { "LIBOCTINTERP", build_env::LIBOCTINTERP },
-           { "LIBS", build_env::LIBS },
-           { "LN_S", build_env::LN_S },
-           { "MAGICK_CPPFLAGS", build_env::MAGICK_CPPFLAGS },
-           { "MAGICK_LDFLAGS", build_env::MAGICK_LDFLAGS },
-           { "MAGICK_LIBS", build_env::MAGICK_LIBS },
-           { "MKOCTFILE_DL_LDFLAGS", build_env::MKOCTFILE_DL_LDFLAGS },
-           { "OCTAVE_LINK_DEPS", build_env::OCTAVE_LINK_DEPS },
-           { "OCTAVE_LINK_OPTS", build_env::OCTAVE_LINK_OPTS },
-           { "OCT_LINK_DEPS", build_env::OCT_LINK_DEPS },
-           { "OCT_LINK_OPTS", build_env::OCT_LINK_OPTS },
-           { "OPENGL_LIBS", build_env::OPENGL_LIBS },
-           { "PCRE_CPPFLAGS", build_env::PCRE_CPPFLAGS },
-           { "PCRE_LDFLAGS", build_env::PCRE_LDFLAGS },
-           { "PCRE_LIBS", build_env::PCRE_LIBS },
-           { "PTHREAD_CFLAGS", build_env::PTHREAD_CFLAGS },
-           { "PTHREAD_LIBS", build_env::PTHREAD_LIBS },
-           { "QHULL_CPPFLAGS", build_env::QHULL_CPPFLAGS },
-           { "QHULL_LDFLAGS", build_env::QHULL_LDFLAGS },
-           { "QHULL_LIBS", build_env::QHULL_LIBS },
-           { "QRUPDATE_CPPFLAGS", build_env::QRUPDATE_CPPFLAGS },
-           { "QRUPDATE_LDFLAGS", build_env::QRUPDATE_LDFLAGS },
-           { "QRUPDATE_LIBS", build_env::QRUPDATE_LIBS },
-           { "QT_CPPFLAGS", build_env::QT_CPPFLAGS },
-           { "QT_LDFLAGS", build_env::QT_LDFLAGS },
-           { "QT_LIBS", build_env::QT_LIBS },
-           { "QT_OPENGL_LIBS", build_env::QT_OPENGL_LIBS },
-           { "RANLIB", build_env::RANLIB },
-           { "RDYNAMIC_FLAG", build_env::RDYNAMIC_FLAG },
-           { "READLINE_LIBS", build_env::READLINE_LIBS },
-           { "SHARED_LIBS", build_env::SHARED_LIBS },
-           { "SH_LDFLAGS", build_env::SH_LDFLAGS },
-           { "STATIC_LIBS", build_env::STATIC_LIBS },
-           { "SUITESPARSECONFIG_LIBS", build_env::SUITESPARSECONFIG_LIBS },
-           { "TERM_LIBS", build_env::TERM_LIBS },
-           { "UMFPACK_CPPFLAGS", build_env::UMFPACK_CPPFLAGS },
-           { "UMFPACK_LDFLAGS", build_env::UMFPACK_LDFLAGS },
-           { "UMFPACK_LIBS", build_env::UMFPACK_LIBS },
-           { "WARN_CFLAGS", build_env::WARN_CFLAGS },
-           { "WARN_CXXFLAGS", build_env::WARN_CXXFLAGS },
-           { "X11_INCFLAGS", build_env::X11_INCFLAGS },
-           { "X11_LIBS", build_env::X11_LIBS },
-           { "XTRA_CFLAGS", build_env::XTRA_CFLAGS },
-           { "XTRA_CXXFLAGS", build_env::XTRA_CXXFLAGS },
-           { "YACC", build_env::YACC },
-           { "YFLAGS", build_env::YFLAGS },
-           { "Z_CPPFLAGS", build_env::Z_CPPFLAGS },
-           { "Z_LDFLAGS", build_env::Z_LDFLAGS },
-           { "Z_LIBS", build_env::Z_LIBS },
-           { "config_opts", build_env::config_opts }};
+      = {{ "AMD_CPPFLAGS", build_env::AMD_CPPFLAGS },
+        { "AMD_LDFLAGS", build_env::AMD_LDFLAGS },
+        { "AMD_LIBS", build_env::AMD_LIBS },
+        { "AR", build_env::AR },
+        { "ARFLAGS", build_env::ARFLAGS },
+        { "ARPACK_CPPFLAGS", build_env::ARPACK_CPPFLAGS },
+        { "ARPACK_LDFLAGS", build_env::ARPACK_LDFLAGS },
+        { "ARPACK_LIBS", build_env::ARPACK_LIBS },
+        { "BLAS_LIBS", build_env::BLAS_LIBS },
+        { "CAMD_CPPFLAGS", build_env::CAMD_CPPFLAGS },
+        { "CAMD_LDFLAGS", build_env::CAMD_LDFLAGS },
+        { "CAMD_LIBS", build_env::CAMD_LIBS },
+        { "CARBON_LIBS", build_env::CARBON_LIBS },
+        { "CC", build_env::CC },
+        { "CCOLAMD_CPPFLAGS", build_env::CCOLAMD_CPPFLAGS },
+        { "CCOLAMD_LDFLAGS", build_env::CCOLAMD_LDFLAGS },
+        { "CCOLAMD_LIBS", build_env::CCOLAMD_LIBS },
+        { "CFLAGS", build_env::CFLAGS },
+        { "CHOLMOD_CPPFLAGS", build_env::CHOLMOD_CPPFLAGS },
+        { "CHOLMOD_LDFLAGS", build_env::CHOLMOD_LDFLAGS },
+        { "CHOLMOD_LIBS", build_env::CHOLMOD_LIBS },
+        { "COLAMD_CPPFLAGS", build_env::COLAMD_CPPFLAGS },
+        { "COLAMD_LDFLAGS", build_env::COLAMD_LDFLAGS },
+        { "COLAMD_LIBS", build_env::COLAMD_LIBS },
+        { "CPICFLAG", build_env::CPICFLAG },
+        { "CPPFLAGS", build_env::CPPFLAGS },
+        { "CURL_CPPFLAGS", build_env::CURL_CPPFLAGS },
+        { "CURL_LDFLAGS", build_env::CURL_LDFLAGS },
+        { "CURL_LIBS", build_env::CURL_LIBS },
+        { "CXSPARSE_CPPFLAGS", build_env::CXSPARSE_CPPFLAGS },
+        { "CXSPARSE_LDFLAGS", build_env::CXSPARSE_LDFLAGS },
+        { "CXSPARSE_LIBS", build_env::CXSPARSE_LIBS },
+        { "CXX", build_env::CXX },
+        { "CXXCPP", build_env::CXXCPP },
+        { "CXXFLAGS", build_env::CXXFLAGS },
+        { "CXXPICFLAG", build_env::CXXPICFLAG },
+        { "DEFS", build_env::DEFS },
+        { "DL_LDFLAGS", build_env::DL_LDFLAGS },
+        { "GCC_VERSION", build_env::GCC_VERSION },
+        { "GXX_VERSION", build_env::GXX_VERSION },
+        { "EXEEXT", build_env::EXEEXT },
+        { "F77", build_env::F77 },
+        { "F77_FLOAT_STORE_FLAG", build_env::F77_FLOAT_STORE_FLAG },
+        { "F77_INTEGER_8_FLAG", build_env::F77_INTEGER_8_FLAG },
+        { "FFLAGS", build_env::FFLAGS },
+        { "FFTW3_CPPFLAGS", build_env::FFTW3_CPPFLAGS },
+        { "FFTW3_LDFLAGS", build_env::FFTW3_LDFLAGS },
+        { "FFTW3_LIBS", build_env::FFTW3_LIBS },
+        { "FFTW3F_CPPFLAGS", build_env::FFTW3F_CPPFLAGS },
+        { "FFTW3F_LDFLAGS", build_env::FFTW3F_LDFLAGS },
+        { "FFTW3F_LIBS", build_env::FFTW3F_LIBS },
+        { "FLIBS", build_env::FLIBS },
+        { "FLTK_CPPFLAGS", build_env::FLTK_CPPFLAGS },
+        { "FLTK_LDFLAGS", build_env::FLTK_LDFLAGS },
+        { "FLTK_LIBS", build_env::FLTK_LIBS },
+        { "FONTCONFIG_CPPFLAGS", build_env::FONTCONFIG_CPPFLAGS },
+        { "FONTCONFIG_LIBS", build_env::FONTCONFIG_LIBS },
+        { "FPICFLAG", build_env::FPICFLAG },
+        { "FT2_CPPFLAGS", build_env::FT2_CPPFLAGS },
+        { "FT2_LIBS", build_env::FT2_LIBS },
+        { "GLPK_CPPFLAGS", build_env::GLPK_CPPFLAGS },
+        { "GLPK_LDFLAGS", build_env::GLPK_LDFLAGS },
+        { "GLPK_LIBS", build_env::GLPK_LIBS },
+        { "GNUPLOT", build_env::GNUPLOT },
+        { "HDF5_CPPFLAGS", build_env::HDF5_CPPFLAGS },
+        { "HDF5_LDFLAGS", build_env::HDF5_LDFLAGS },
+        { "HDF5_LIBS", build_env::HDF5_LIBS },
+        { "LAPACK_LIBS", build_env::LAPACK_LIBS },
+        { "LDFLAGS", build_env::LDFLAGS },
+        { "LD_STATIC_FLAG", build_env::LD_STATIC_FLAG },
+        { "LEX", build_env::LEX },
+        { "LEXLIB", build_env::LEXLIB },
+        { "LFLAGS", build_env::LFLAGS },
+        { "LIBOCTAVE", build_env::LIBOCTAVE },
+        { "LIBOCTINTERP", build_env::LIBOCTINTERP },
+        { "LIBS", build_env::LIBS },
+        { "LN_S", build_env::LN_S },
+        { "MAGICK_CPPFLAGS", build_env::MAGICK_CPPFLAGS },
+        { "MAGICK_LDFLAGS", build_env::MAGICK_LDFLAGS },
+        { "MAGICK_LIBS", build_env::MAGICK_LIBS },
+        { "MKOCTFILE_DL_LDFLAGS", build_env::MKOCTFILE_DL_LDFLAGS },
+        { "OCTAVE_LINK_DEPS", build_env::OCTAVE_LINK_DEPS },
+        { "OCTAVE_LINK_OPTS", build_env::OCTAVE_LINK_OPTS },
+        { "OCT_LINK_DEPS", build_env::OCT_LINK_DEPS },
+        { "OCT_LINK_OPTS", build_env::OCT_LINK_OPTS },
+        { "OPENGL_LIBS", build_env::OPENGL_LIBS },
+        { "PCRE_CPPFLAGS", build_env::PCRE_CPPFLAGS },
+        { "PCRE_LDFLAGS", build_env::PCRE_LDFLAGS },
+        { "PCRE_LIBS", build_env::PCRE_LIBS },
+        { "PTHREAD_CFLAGS", build_env::PTHREAD_CFLAGS },
+        { "PTHREAD_LIBS", build_env::PTHREAD_LIBS },
+        { "QHULL_CPPFLAGS", build_env::QHULL_CPPFLAGS },
+        { "QHULL_LDFLAGS", build_env::QHULL_LDFLAGS },
+        { "QHULL_LIBS", build_env::QHULL_LIBS },
+        { "QRUPDATE_CPPFLAGS", build_env::QRUPDATE_CPPFLAGS },
+        { "QRUPDATE_LDFLAGS", build_env::QRUPDATE_LDFLAGS },
+        { "QRUPDATE_LIBS", build_env::QRUPDATE_LIBS },
+        { "QT_CPPFLAGS", build_env::QT_CPPFLAGS },
+        { "QT_LDFLAGS", build_env::QT_LDFLAGS },
+        { "QT_LIBS", build_env::QT_LIBS },
+        { "QT_OPENGL_LIBS", build_env::QT_OPENGL_LIBS },
+        { "RANLIB", build_env::RANLIB },
+        { "RDYNAMIC_FLAG", build_env::RDYNAMIC_FLAG },
+        { "READLINE_LIBS", build_env::READLINE_LIBS },
+        { "SHARED_LIBS", build_env::SHARED_LIBS },
+        { "SH_LDFLAGS", build_env::SH_LDFLAGS },
+        { "STATIC_LIBS", build_env::STATIC_LIBS },
+        { "SUITESPARSECONFIG_LIBS", build_env::SUITESPARSECONFIG_LIBS },
+        { "UMFPACK_CPPFLAGS", build_env::UMFPACK_CPPFLAGS },
+        { "UMFPACK_LDFLAGS", build_env::UMFPACK_LDFLAGS },
+        { "UMFPACK_LIBS", build_env::UMFPACK_LIBS },
+        { "WARN_CFLAGS", build_env::WARN_CFLAGS },
+        { "WARN_CXXFLAGS", build_env::WARN_CXXFLAGS },
+        { "X11_INCFLAGS", build_env::X11_INCFLAGS },
+        { "X11_LIBS", build_env::X11_LIBS },
+        { "XTRA_CFLAGS", build_env::XTRA_CFLAGS },
+        { "XTRA_CXXFLAGS", build_env::XTRA_CXXFLAGS },
+        { "YACC", build_env::YACC },
+        { "YFLAGS", build_env::YFLAGS },
+        { "Z_CPPFLAGS", build_env::Z_CPPFLAGS },
+        { "Z_LDFLAGS", build_env::Z_LDFLAGS },
+        { "Z_LIBS", build_env::Z_LIBS },
+        { "config_opts", build_env::config_opts }
+      };
 
       config = octave_scalar_map (conf_info_map);
       build_env = octave_scalar_map (build_env_map);
@@ -615,7 +614,8 @@ specified option.
 
   if (nargin == 1)
     {
-      std::string arg = args(0).xstring_value ("__octave_config_info__: OPTION argument must be a string");
+      std::string arg = args(
+                          0).xstring_value ("__octave_config_info__: OPTION argument must be a string");
 
       octave_value info = find_config_info (config, arg);
 
@@ -648,7 +648,7 @@ specified option.
 %!error __octave_config_info__ (1, 2)
 */
 
-OCTAVE_NAMESPACE_END
+OCTAVE_END_NAMESPACE(octave)
 
 #if defined (__GNUG__) && defined (DEBUG_NEW_DELETE)
 
