@@ -1,24 +1,27 @@
-/*
-
-Copyright (C) 2010-2019 Kai Habel
-
-This file is part of Octave.
-
-Octave is free software: you can redistribute it and/or modify it
-under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Octave is distributed in the hope that it will be useful, but
-WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, see
-<https://www.gnu.org/licenses/>.
-
-*/
+////////////////////////////////////////////////////////////////////////
+//
+// Copyright (C) 2010-2023 The Octave Project Developers
+//
+// See the file COPYRIGHT.md in the top-level directory of this
+// distribution or <https://octave.org/copyright/>.
+//
+// This file is part of Octave.
+//
+// Octave is free software: you can redistribute it and/or modify it
+// under the terms of the GNU General Public License as published by
+// the Free Software Foundation, either version 3 of the License, or
+// (at your option) any later version.
+//
+// Octave is distributed in the hope that it will be useful, but
+// WITHOUT ANY WARRANTY; without even the implied warranty of
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+// GNU General Public License for more details.
+//
+// You should have received a copy of the GNU General Public License
+// along with Octave; see the file COPYING.  If not, see
+// <https://www.gnu.org/licenses/>.
+//
+////////////////////////////////////////////////////////////////////////
 
 #if defined (HAVE_CONFIG_H)
 #  include "config.h"
@@ -26,20 +29,20 @@ along with Octave; see the file COPYING.  If not, see
 
 #if defined (HAVE_FLTK)
 
-#if defined (WIN32)
-#  define WIN32_LEAN_AND_MEAN
-#endif
+#  if defined (WIN32)
+#    define WIN32_LEAN_AND_MEAN
+#  endif
 
-#include <string>
+#  include <string>
 
-#include <FL/Fl.H>
-#include <FL/Fl_File_Chooser.H>
+#  include <FL/Fl.H>
+#  include <FL/Fl_File_Chooser.H>
 
 // FLTK headers may include X11/X.h which defines Complex, and that
 // conflicts with Octave's Complex typedef.  We don't need the X11
 // Complex definition in this file, so remove it before including Octave
 // headers which may require Octave's Complex typedef.
-#undef Complex
+#  undef Complex
 
 #endif
 
@@ -51,9 +54,11 @@ along with Octave; see the file COPYING.  If not, see
 #include "errwarn.h"
 #include "ov.h"
 
+OCTAVE_BEGIN_NAMESPACE(octave)
+
 DEFUN_DLD (__fltk_uigetfile__, args, ,
            doc: /* -*- texinfo -*-
-@deftypefn {} {} __fltk_uigetfile__ (@dots{})
+@deftypefn {} {[@var{fname}, @var{fpath}, @var{fltidx}] =} __fltk_uigetfile__ (@dots{})
 Undocumented internal function.
 @end deftypefn */)
 {
@@ -64,20 +69,18 @@ Undocumented internal function.
   //   args(0) ... FileFilter in fltk format
   //   args(1) ... Title
   //   args(2) ... Default Filename
-  //   args(3) ... PositionValue [x,y]
-  //   args(4) ... SelectValue "on"/"off"/"dir"/"create"
+  //   args(3) ... SelectValue "on"/"off"/"dir"/"create"
 
   octave_value_list retval (3, octave_value (0));
 
   std::string file_filter = args(0).string_value ();
   std::string title = args(1).string_value ();
   std::string default_name = args(2).string_value ();
-  Matrix pos = args(3).matrix_value ();
 
   int multi_type = Fl_File_Chooser::SINGLE;
   std::string flabel = "Filename:";
 
-  std::string multi = args(4).string_value ();
+  std::string multi = args(3).string_value ();
   if (multi == "on")
     multi_type = Fl_File_Chooser::MULTI;
   else if (multi == "dir")
@@ -110,7 +113,7 @@ Undocumented internal function.
 
       // FLTK uses forward slash even for Windows
       std::string sep = "/";
-      size_t idx;
+      std::size_t idx;
 
       if (file_count == 1 && multi_type != Fl_File_Chooser::DIRECTORY)
         {
@@ -131,12 +134,10 @@ Undocumented internal function.
         }
 
       if (multi_type == Fl_File_Chooser::DIRECTORY)
-        retval(0) = octave::sys::file_ops::native_separator_path (
-                      std::string (fc.value ()));
+        retval(0) = sys::file_ops::native_separator_path (std::string (fc.value ()));
       else
         {
-          retval(1) = octave::sys::file_ops::native_separator_path (
-                        std::string (fc.directory ()) + sep);
+          retval(1) = sys::file_ops::native_separator_path (std::string (fc.directory ()) + sep);
           retval(2) = fc.filter_value () + 1;
         }
     }
@@ -159,3 +160,5 @@ Undocumented internal function.
 ## No test needed for internal helper function.
 %!assert (1)
 */
+
+OCTAVE_END_NAMESPACE(octave)
