@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 2006-2021 The Octave Project Developers
+// Copyright (C) 2006-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -31,11 +31,12 @@
 
 #include "octave-config.h"
 
-namespace octave
-{
-  template <typename T> void rand_poisson (T L, octave_idx_type n, T *p);
+OCTAVE_BEGIN_NAMESPACE(octave)
 
-  template <typename T> T rand_poisson (T L);
-}
+template <typename T> OCTAVE_API void rand_poisson (T L, octave_idx_type n, T *p);
+
+template <typename T> OCTAVE_API T rand_poisson (T L);
+
+OCTAVE_END_NAMESPACE(octave)
 
 #endif
