@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////
 //
-// Copyright (C) 1996-2020 The Octave Project Developers
+// Copyright (C) 1996-2023 The Octave Project Developers
 //
 // See the file COPYRIGHT.md in the top-level directory of this
 // distribution or <https://octave.org/copyright/>.
@@ -38,45 +38,40 @@
 
 #include "quit.h"
 
+#include "intprops-wrappers.h"
 #include "lo-error.h"
 #include "lo-ieee.h"
 #include "lo-mappers.h"
 #include "lo-utils.h"
+#include "oct-inttypes.h"
 
-bool xis_int_or_inf_or_nan (double x)
-{ return octave::math::isnan (x) || octave::math::x_nint (x) == x; }
+OCTAVE_BEGIN_NAMESPACE(octave)
 
-bool xis_one_or_zero (double x)
-{ return x == 0 || x == 1; }
-
-bool xis_zero (double x)
-{ return x == 0; }
-
-bool xtoo_large_for_float (double x)
+bool is_int_or_inf_or_nan (double x)
 {
-  return (octave::math::isfinite (x)
+  return math::isnan (x) || math::x_nint (x) == x;
+}
+
+bool too_large_for_float (double x)
+{
+  return (math::isfinite (x)
           && fabs (x) > std::numeric_limits<float>::max ());
 }
 
-bool xtoo_large_for_float (const Complex& x)
+bool too_large_for_float (const Complex& x)
 {
-  return (xtoo_large_for_float (x.real ())
-          || xtoo_large_for_float (x.imag ()));
+  return (too_large_for_float (x.real ())
+          || too_large_for_float (x.imag ()));
 }
 
-bool xis_int_or_inf_or_nan (float x)
-{ return octave::math::isnan (x) || octave::math::x_nint (x) == x; }
-
-bool xis_one_or_zero (float x)
-{ return x == 0 || x == 1; }
-
-bool xis_zero (float x)
-{ return x == 0; }
+bool is_int_or_inf_or_nan (float x)
+{
+  return math::isnan (x) || math::x_nint (x) == x;
+}
 
 // Save a string.
 
-char *
-strsave (const char *s)
+char * strsave (const char *s)
 {
   if (! s)
     return nullptr;
@@ -87,15 +82,13 @@ strsave (const char *s)
   return tmp;
 }
 
-std::string
-octave_fgets (FILE *f)
+std::string fgets (FILE *f)
 {
   bool eof;
-  return octave_fgets (f, eof);
+  return fgets (f, eof);
 }
 
-std::string
-octave_fgets (FILE *f, bool& eof)
+std::string fgets (FILE *f, bool& eof)
 {
   eof = false;
 
@@ -169,17 +162,15 @@ octave_fgets (FILE *f, bool& eof)
   return retval;
 }
 
-std::string
-octave_fgetl (FILE *f)
+std::string fgetl (FILE *f)
 {
   bool eof;
-  return octave_fgetl (f, eof);
+  return fgetl (f, eof);
 }
 
-std::string
-octave_fgetl (FILE *f, bool& eof)
+std::string fgetl (FILE *f, bool& eof)
 {
-  std::string retval = octave_fgets (f, eof);
+  std::string retval = fgets (f, eof);
 
   if (! retval.empty () && retval.back () == '\n')
     retval.pop_back ();
@@ -187,7 +178,27 @@ octave_fgetl (FILE *f, bool& eof)
   return retval;
 }
 
-// Note that the caller is responsible for repositioning the stream on failure.
+template <typename T>
+T
+read_value (std::istream& is)
+{
+  T retval;
+  is >> retval;
+  return retval;
+}
+
+template OCTAVE_API bool read_value<bool> (std::istream& is);
+template OCTAVE_API octave_int8 read_value<octave_int8> (std::istream& is);
+template OCTAVE_API octave_int16 read_value<octave_int16> (std::istream& is);
+template OCTAVE_API octave_int32 read_value<octave_int32> (std::istream& is);
+template OCTAVE_API octave_int64 read_value<octave_int64> (std::istream& is);
+template OCTAVE_API octave_uint8 read_value<octave_uint8> (std::istream& is);
+template OCTAVE_API octave_uint16 read_value<octave_uint16> (std::istream& is);
+template OCTAVE_API octave_uint32 read_value<octave_uint32> (std::istream& is);
+template OCTAVE_API octave_uint64 read_value<octave_uint64> (std::istream& is);
+
+// Note that the caller is responsible for repositioning the stream on
+// failure.
 
 template <typename T>
 T
@@ -223,7 +234,7 @@ read_inf_nan_na (std::istream& is, char c0)
               val = std::numeric_limits<T>::quiet_NaN ();
             else
               {
-                val = octave::numeric_limits<T>::NA ();
+                val = numeric_limits<T>::NA ();
                 if (c2 != std::istream::traits_type::eof ())
                   is.putback (c2);
                 else
@@ -247,7 +258,7 @@ read_inf_nan_na (std::istream& is, char c0)
 
 template <typename T>
 double
-octave_read_fp_value (std::istream& is)
+read_fp_value (std::istream& is)
 {
   T val = 0.0;
 
@@ -322,7 +333,7 @@ octave_read_fp_value (std::istream& is)
 
 template <typename T>
 std::complex<T>
-octave_read_cx_fp_value (std::istream& is)
+read_cx_fp_value (std::istream& is)
 {
   T re = 0.0;
   T im = 0.0;
@@ -336,12 +347,12 @@ octave_read_cx_fp_value (std::istream& is)
 
   if (ch == '(')
     {
-      re = octave_read_value<T> (is);
+      re = read_value<T> (is);
       ch = is.get ();
 
       if (ch == ',')
         {
-          im = octave_read_value<T> (is);
+          im = read_value<T> (is);
           ch = is.get ();
 
           if (ch == ')')
@@ -357,74 +368,153 @@ octave_read_cx_fp_value (std::istream& is)
   else
     {
       is.putback (ch);
-      cx = octave_read_value<double> (is);
+      cx = read_value<T> (is);
     }
 
   return cx;
 }
 
-template <> OCTAVE_API double octave_read_value (std::istream& is)
+// FIXME: Could we use traits and enable_if to avoid duplication in the
+// following specializations?
+
+template <> OCTAVE_API double read_value (std::istream& is)
 {
-  return octave_read_fp_value<double> (is);
+                                          return read_fp_value<double> (is);
 }
 
-template <> OCTAVE_API Complex octave_read_value (std::istream& is)
+template <> OCTAVE_API Complex read_value (std::istream& is)
 {
-  return octave_read_cx_fp_value<double> (is);
+                                           return read_cx_fp_value<double> (is);
 }
 
-template <> OCTAVE_API float octave_read_value (std::istream& is)
+template <> OCTAVE_API float read_value (std::istream& is)
 {
-  return octave_read_fp_value<float> (is);
+                                         return read_fp_value<float> (is);
 }
 
-template <> OCTAVE_API FloatComplex octave_read_value (std::istream& is)
+template <> OCTAVE_API FloatComplex read_value (std::istream& is)
 {
-  return octave_read_cx_fp_value<float> (is);
+                                                return read_cx_fp_value<float> (is);
 }
 
+template <typename T>
 void
-octave_write_double (std::ostream& os, double d)
+write_value (std::ostream& os, const T& value)
 {
-  if (lo_ieee_is_NA (d))
+  os << value;
+}
+
+template OCTAVE_API void
+write_value<bool> (std::ostream& os, const bool& value);
+template OCTAVE_API void
+write_value<octave_int8> (std::ostream& os, const octave_int8& value);
+template OCTAVE_API void
+write_value<octave_int16> (std::ostream& os, const octave_int16& value);
+template OCTAVE_API void
+write_value<octave_int32> (std::ostream& os, const octave_int32& value);
+template OCTAVE_API void
+write_value<octave_int64> (std::ostream& os, const octave_int64& value);
+template OCTAVE_API void
+write_value<octave_uint8> (std::ostream& os, const octave_uint8& value);
+template OCTAVE_API void
+write_value<octave_uint16> (std::ostream& os, const octave_uint16& value);
+template OCTAVE_API void
+write_value<octave_uint32> (std::ostream& os, const octave_uint32& value);
+template OCTAVE_API void
+write_value<octave_uint64> (std::ostream& os, const octave_uint64& value);
+
+// Note: precision is supposed to be managed outside of this function by
+// setting stream parameters.
+
+template <> OCTAVE_API void
+write_value (std::ostream& os, const double& value)
+{
+  if (lo_ieee_is_NA (value))
     os << "NA";
-  else if (lo_ieee_isnan (d))
+  else if (lo_ieee_isnan (value))
     os << "NaN";
-  else if (lo_ieee_isinf (d))
-    os << (d < 0 ? "-Inf" : "Inf");
+  else if (lo_ieee_isinf (value))
+    os << (value < 0 ? "-Inf" : "Inf");
   else
-    os << d;
+    os << value;
 }
 
-void
-octave_write_complex (std::ostream& os, const Complex& c)
+template <> OCTAVE_API void
+write_value (std::ostream& os, const Complex& value)
 {
   os << '(';
-  octave_write_double (os, real (c));
+  write_value<double> (os, real (value));
   os << ',';
-  octave_write_double (os, imag (c));
+  write_value<double> (os, imag (value));
   os << ')';
 }
 
-void
-octave_write_float (std::ostream& os, float d)
+// Note: precision is supposed to be managed outside of this function by
+// setting stream parameters.
+
+template <> OCTAVE_API void
+write_value (std::ostream& os, const float& value)
 {
-  if (lo_ieee_is_NA (d))
+  if (lo_ieee_is_NA (value))
     os << "NA";
-  else if (lo_ieee_isnan (d))
+  else if (lo_ieee_isnan (value))
     os << "NaN";
-  else if (lo_ieee_isinf (d))
-    os << (d < 0 ? "-Inf" : "Inf");
+  else if (lo_ieee_isinf (value))
+    os << (value < 0 ? "-Inf" : "Inf");
   else
-    os << d;
+    os << value;
 }
 
-void
-octave_write_float_complex (std::ostream& os, const FloatComplex& c)
+template <> OCTAVE_API void
+write_value (std::ostream& os, const FloatComplex& value)
 {
   os << '(';
-  octave_write_float (os, real (c));
+  write_value<float> (os, real (value));
   os << ',';
-  octave_write_float (os, imag (c));
+  write_value<float> (os, imag (value));
   os << ')';
 }
+
+OCTAVE_BEGIN_NAMESPACE(math)
+
+bool int_multiply_overflow (int a, int b, int *r)
+{
+  return octave_i_multiply_overflow_wrapper (a, b, r);
+}
+
+bool int_multiply_overflow (long int a, long int b, long int *r)
+{
+  return octave_li_multiply_overflow_wrapper (a, b, r);
+}
+
+#if defined (OCTAVE_HAVE_LONG_LONG_INT)
+bool int_multiply_overflow (long long int a, long long int b,
+                            long long int *r)
+{
+  return octave_lli_multiply_overflow_wrapper (a, b, r);
+}
+#endif
+
+bool int_multiply_overflow (unsigned int a, unsigned int b,
+                            unsigned int *r)
+{
+  return octave_ui_multiply_overflow_wrapper (a, b, r);
+}
+
+bool int_multiply_overflow (unsigned long int a, unsigned long int b,
+                            unsigned long int *r)
+{
+  return octave_uli_multiply_overflow_wrapper (a, b, r);
+}
+
+#if defined (OCTAVE_HAVE_UNSIGNED_LONG_LONG_INT)
+bool int_multiply_overflow (unsigned long long int a,
+                            unsigned long long int b,
+                            unsigned long long int *r)
+{
+  return octave_ulli_multiply_overflow_wrapper (a, b, r);
+}
+#endif
+
+OCTAVE_END_NAMESPACE(math)
+OCTAVE_END_NAMESPACE(octave)
