@@ -1,6 +1,6 @@
 ########################################################################
 ##
-## Copyright (C) 2010-2020 The Octave Project Developers
+## Copyright (C) 2010-2023 The Octave Project Developers
 ##
 ## See the file COPYRIGHT.md in the top-level directory of this
 ## distribution or <https://octave.org/copyright/>.
@@ -41,10 +41,6 @@
 
 function dirname = uigetdir (init_path = pwd, dialog_name = "Select Directory to Open")
 
-  if (nargin > 2)
-    print_usage ();
-  endif
-
   if (! ischar (init_path) || ! ischar (dialog_name))
     error ("uigetdir: INIT_PATH and DIALOG_NAME must be string arguments");
   endif
@@ -53,16 +49,15 @@ function dirname = uigetdir (init_path = pwd, dialog_name = "Select Directory to
     init_path = fileparts (init_path);
   endif
 
-  if (__event_manager_enabled__ ())
+  if (__event_manager_have_dialogs__ ())
     file_filter = cell (0, 2);
     default_file_name = "";
-    dialog_position = [240, 120];
     dialog_mode = "dir";
 
     [filename, dirname, filterindex] ...
       = __event_manager_file_dialog__ (file_filter, dialog_name,
-                                     default_file_name, dialog_position,
-                                     dialog_mode, init_path);
+                                       default_file_name, dialog_mode,
+                                       init_path);
   else
     funcname = __get_funcname__ (mfilename ());
     dirname = feval (funcname, init_path, dialog_name);
