@@ -1,6 +1,9 @@
-## Copyright (C) 2010-2019 John W. Eaton
-## Copyright (C) 2010 VZLU Prague
-## Copyright (C) 2017-2019 Colin B. Macdonald
+########################################################################
+##
+## Copyright (C) 2010-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -17,6 +20,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
 ## @deftypefn {} {@var{txt} =} __unimplemented__ (@var{fcn})
@@ -34,7 +39,7 @@
 
 function txt = __unimplemented__ (fcn)
 
-  if (nargin != 1)
+  if (nargin < 1)
     print_usage ();
   endif
 
@@ -46,10 +51,6 @@ function txt = __unimplemented__ (fcn)
       txt = ["Basic video file support is provided in the video package.  ", ...
              "See @url{https://octave.sourceforge.io/video/}."];
 
-    case "exifread"
-      txt = ["exifread is deprecated.  " ...
-             "The functionality is available in the imfinfo function."];
-
     case "funm"
       txt = ["funm is not currently part of core Octave.  ", ...
              "See the linear-algebra package at ", ...
@@ -68,11 +69,12 @@ function txt = __unimplemented__ (fcn)
       txt = ["matlabrc is not implemented.  ", ...
              "Octave uses the file '.octaverc' instead."];
 
-    case {"ode113", "ode15i", "ode15s", "ode23s", "ode23t", "ode23tb"}
-      txt = ["Octave provides lsode and ode45 for solving differential equations. ", ...
-             "For more information try @code{help lsode}, @code{help ode45}.  ", ...
-             "Matlab-compatible ODE functions are provided by the odepkg ", ...
-             "package.  See @url{https://octave.sourceforge.io/odepkg/}."];
+    case {"ode113", "ode23t", "ode23tb"}
+      txt = ["Octave provides lsode and ode15i, ode15s, ode23, ode23s, ", ...
+             "and ode45 for solving differential equations.  For more", ...
+             "information try @code{help lsode}, @code{help ode45}.  ", ...
+             "Further specialized ODE solvers are provided by the odepkg ", ...
+             "package.  See @url{https://wiki.octave.org/Odepkg}."];
 
     case "polarplot"
       txt = ["polarplot is not implemented.  Consider using polar."];
@@ -162,6 +164,15 @@ function txt = __unimplemented__ (fcn)
           "vec2mat", "vitdec", "wgn"}
       txt = check_package (fcn, "communications");
 
+    ## dicom
+    case {"addContour", "convertToInfo", "dicomanon", "dicomBrowser", ...
+          "dicomCollection", "dicomContours", "dicomdict", "dicomdisp", ...
+          "dicominfo", "dicomlookup", "dicomread", "dicomreadVolume", ...
+          "dicomuid", "dicomwrite", "deleteContour", ...
+          "images.dicom.decodeUID", "images.dicom.parseDICOMDIR", "isdicom", ...
+          "plotContour"}
+      txt = check_package (fcn, "dicom");
+
     ## finance
     case {"abs2active", "accrfrac", "acrubond", "acrudisc", "active2abs", ...
           "addEquality", "addGroupRatio", "addGroups", "addInequality", ...
@@ -270,21 +281,20 @@ function txt = __unimplemented__ (fcn)
           "cornermetric", "corr2", "cp2tform", "cpcorr", "cpselect", ...
           "cpstruct2pairs", "dct2", "dctmtx", "deconvblind", "deconvlucy", ...
           "deconvreg", "deconvwnr", "decorrstretch", "demosaic", ...
-          "dicomanon", "dicomdict", "dicominfo", "dicomlookup", "dicomread", ...
-          "dicomuid", "dicomwrite", "edge", "edgetaper", "entropy", ...
-          "entropyfilt", "fan2para", "fanbeam", "findbounds", "fitgeotrans", ...
-          "fliptform", "freqz2", "fsamp2", "fspecial", "ftrans2", "fwind1", ...
-          "fwind2", "getheight", "getimage", "getimagemodel", "getline", ...
-          "getneighbors", "getnhood", "getpts", "getrect", "getsequence", ...
-          "graycomatrix", "graycoprops", "graydist", "grayslice", ...
-          "graythresh", "hdrread", "hdrwrite", "histeq", "hough", ...
-          "houghlines", "houghpeaks", "iccfind", "iccread", "iccroot", ...
-          "iccwrite", "idct2", "ifanbeam", "im2bw", "im2col", "im2double", ...
-          "im2int16", "im2java2d", "im2single", "im2uint16", "im2uint8", ...
-          "imabsdiff", "imadd", "imadjust", "ImageAdapter", "imageinfo", ...
-          "imapplymatrix", "imapprox", "imattributes", "imbothat", ...
-          "imclearborder", "imclose", "imcolormaptool", "imcomplement", ...
-          "imcontour", "imcontrast", "imcrop", "imdilate", "imdisplayrange", ...
+          "edge", "edgetaper", "entropy", "entropyfilt", "fan2para", ...
+          "fanbeam", "findbounds", "fitgeotrans", "fliptform", "freqz2", ...
+          "fsamp2", "fspecial", "ftrans2", "fwind1", "fwind2", "getheight", ...
+          "getimage", "getimagemodel", "getline", "getneighbors", ...
+          "getnhood", "getpts", "getrect", "getsequence", "graycomatrix", ...
+          "graycoprops", "graydist", "grayslice", "graythresh", "hdrread", ...
+          "hdrwrite", "histeq", "hough", "houghlines", "houghpeaks", ...
+          "iccfind", "iccread", "iccroot", "iccwrite", "idct2", "ifanbeam", ...
+          "im2bw", "im2col", "im2double", "im2int16", "im2java2d", ...
+          "im2single", "im2uint16", "im2uint8", "imabsdiff", "imadd", ...
+          "imadjust", "ImageAdapter", "imageinfo", "imapplymatrix", ...
+          "imapprox", "imattributes", "imbothat", "imclearborder", ...
+          "imclose", "imcolormaptool", "imcomplement", "imcontour", ...
+          "imcontrast", "imcrop", "imdilate", "imdisplayrange", ...
           "imdistline", "imdivide", "imellipse", "imerode", "imextendedmax", ...
           "imextendedmin", "imfill", "imfilter", "imfindcircles", ...
           "imfreehand", "imfuse", "imgca", "imgcf", "imgetfile", ...
@@ -508,7 +518,7 @@ function txt = __unimplemented__ (fcn)
 
     otherwise
       if (ismember (fcn, missing_functions ()))
-        txt = ["the '" fcn "' function is not yet implemented in Octave"];
+        txt = ["The '" fcn "' function is not yet implemented in Octave."];
       else
         is_matlab_function = false;
         txt = "";
@@ -523,7 +533,7 @@ function txt = __unimplemented__ (fcn)
   endif
 
   if (nargout == 0)
-    warning ("Octave:missing-function", "%s\n", txt);
+    error ("Octave:missing-function", "%s\n", txt);
   endif
 
 endfunction
@@ -534,7 +544,7 @@ function txt = check_package (fcn, name, classes)
     classes = {};
   endif
 
-  txt = sprintf ("the '%s' function belongs to the %s package from Octave Forge",
+  txt = sprintf ("The '%s' function belongs to the %s package from Octave Forge",
                  fcn, name);
 
   [~, status] = pkg ("describe", name);
@@ -551,13 +561,13 @@ function txt = check_package (fcn, name, classes)
           txt = sprintf (["'%s' is a method of class '%s'; it must be ", ...
                           "called with a '%s' argument (see 'help @@%s/%s')."],
                          fcn, cls, cls, cls, fcn);
-          return
+          return;
         endif
       endfor
       txt = sprintf ("%s but has not yet been implemented.", txt);
     case "not loaded",
       txt = sprintf (["%s which you have installed but not loaded.  To ", ...
-                      "load the package, run `pkg load %s' from the ", ...
+                      "load the package, run 'pkg load %s' from the ", ...
                       "Octave prompt."], txt, name);
     otherwise
       ## this includes "not installed" and anything else if pkg changes
@@ -568,6 +578,7 @@ function txt = check_package (fcn, name, classes)
 endfunction
 
 function rlist = missing_functions ()
+
   persistent list = {
   "addboundary",
   "addcats",
@@ -649,7 +660,6 @@ function rlist = missing_functions ()
   "circumcenter",
   "circumcenters",
   "classUnderlying",
-  "clearAllMemoizedCaches",
   "clearCache",
   "clearpoints",
   "clipboard",
@@ -658,8 +668,6 @@ function rlist = missing_functions ()
   "collapse",
   "colordef",
   "colormapeditor",
-  "commandhistory",
-  "commandwindow",
   "compose",
   "condensation",
   "coneplot",
@@ -728,7 +736,6 @@ function rlist = missing_functions ()
   "edges",
   "empty",
   "enableservice",
-  "endsWith",
   "enumeration",
   "eraseBetween",
   "eventlisteners",
@@ -747,12 +754,10 @@ function rlist = missing_functions ()
   "Feval",
   "fewerbins",
   "figurepalette",
-  "filebrowser",
   "FileDatastore",
   "filemarker",
   "fileMode",
   "fileName",
-  "fill3",
   "fillmissing",
   "filloutliers",
   "fimplicit",
@@ -806,7 +811,6 @@ function rlist = missing_functions ()
   "getNumOutputs",
   "getNumRows",
   "getOpenFiles",
-  "getpixelposition",
   "getpoints",
   "getProfiles",
   "getqualitydesc",
@@ -952,8 +956,6 @@ function rlist = missing_functions ()
   "javaMethodEDT",
   "javaObjectEDT",
   "join",
-  "jsondecode",
-  "jsonencode",
   "juliandate",
   "labeledge",
   "labelnode",
@@ -967,9 +969,7 @@ function rlist = missing_functions ()
   "libisloaded",
   "libpointer",
   "libstruct",
-  "lightangle",
   "linkdata",
-  "listfonts",
   "loadlibrary",
   "lsqminnorm",
   "lsqr",
@@ -980,19 +980,13 @@ function rlist = missing_functions ()
   "maxflow",
   "MaximizeCommandWindow",
   "maxk",
-  "maxNumCompThreads",
   "memmapfile",
-  "memoize",
   "MemoizedFunction",
-  "memory",
   "mergecats",
   "meta.abstractDetails",
-  "meta.class.fromName",
   "meta.DynamicProperty",
   "meta.EnumeratedValue",
   "meta.MetaData",
-  "meta.package.fromName",
-  "meta.package.getAllPackages",
   "methodsview",
   "MException",
   "milliseconds",
@@ -1016,24 +1010,6 @@ function rlist = missing_functions ()
   "mput",
   "multibandread",
   "multibandwrite",
-  "mustBeFinite",
-  "mustBeGreaterThan",
-  "mustBeGreaterThanOrEqual",
-  "mustBeInteger",
-  "mustBeLessThan",
-  "mustBeLessThanOrEqual",
-  "mustBeMember",
-  "mustBeNegative",
-  "mustBeNonempty",
-  "mustBeNonNan",
-  "mustBeNonnegative",
-  "mustBeNonpositive",
-  "mustBeNonsparse",
-  "mustBeNonzero",
-  "mustBeNumeric",
-  "mustBeNumericOrLogical",
-  "mustBePositive",
-  "mustBeReal",
   "NaT",
   "nccreate",
   "ncdisp",
@@ -1047,7 +1023,6 @@ function rlist = missing_functions ()
   "nearestNeighbor",
   "neighbors",
   "netcdf",
-  "newline",
   "noanimate",
   "notebook",
   "notify",
@@ -1061,13 +1036,11 @@ function rlist = missing_functions ()
   "numRegions",
   "numsides",
   "ode113",
-  "ode23s",
   "ode23t",
   "ode23tb",
   "odextend",
   "openFile",
   "opengl",
-  "ordqz",
   "outdegree",
   "outerjoin",
   "pad",
@@ -1100,7 +1073,6 @@ function rlist = missing_functions ()
   "printpreview",
   "profsave",
   "propedit",
-  "properties",
   "propertyeditor",
   "PutCharArray",
   "PutFullMatrix",
@@ -1143,10 +1115,8 @@ function rlist = missing_functions ()
   "replace",
   "replaceBetween",
   "resample",
-  "rescale",
   "retime",
   "reverse",
-  "rgb2gray",
   "rlim",
   "rmboundary",
   "rmedge",
@@ -1154,7 +1124,6 @@ function rlist = missing_functions ()
   "rmmissing",
   "rmnode",
   "rmslivers",
-  "rng",
   "rowfun",
   "rtickangle",
   "rtickformat",
@@ -1179,7 +1148,6 @@ function rlist = missing_functions ()
   "setHCompSmooth",
   "setinterpmethod",
   "setpixelposition",
-  "setstr",
   "setTileDim",
   "settimeseriesnames",
   "setTscale",
@@ -1207,18 +1175,12 @@ function rlist = missing_functions ()
   "ss2tf",
   "stack",
   "standardizeMissing",
-  "startsWith",
   "stats",
   "step",
   "stopasync",
   "str2mat",
-  "stream2",
-  "stream3",
-  "streamline",
   "streamparticles",
-  "streamribbon",
   "streamslice",
-  "streamtube",
   "string",
   "strings",
   "strip",
@@ -1288,7 +1250,6 @@ function rlist = missing_functions ()
   "uiconfirm",
   "uidropdown",
   "uieditfield",
-  "uifigure",
   "uigauge",
   "uigetpref",
   "uiimport",
@@ -1300,7 +1261,6 @@ function rlist = missing_functions ()
   "uiradiobutton",
   "uisave",
   "uisetcolor",
-  "uisetfont",
   "uisetpref",
   "uislider",
   "uispinner",
@@ -1313,7 +1273,6 @@ function rlist = missing_functions ()
   "uitree",
   "uitreenode",
   "undocheckout",
-  "uniquetol",
   "unloadlibrary",
   "unmesh",
   "unregisterallevents",
@@ -1325,7 +1284,6 @@ function rlist = missing_functions ()
   "varfun",
   "vartype",
   "verctrl",
-  "verLessThan",
   "vertexAttachments",
   "vertexNormal",
   "VideoReader",
@@ -1335,18 +1293,13 @@ function rlist = missing_functions ()
   "volume",
   "volumebounds",
   "voronoiDiagram",
-  "web",
-  "weboptions",
-  "webread",
   "websave",
-  "webwrite",
   "week",
   "whatsnew",
   "width",
   "winopen",
   "withtol",
   "wordcloud",
-  "workspace",
   "write",
   "writeChecksum",
   "writeCol",
@@ -1358,29 +1311,34 @@ function rlist = missing_functions ()
   "writeKeyUnit",
   "writetable",
   "writeVideo",
+  "xline",
   "xmlread",
   "xmlwrite",
   "xslt",
-  "xtickangle",
   "xtickformat",
   "year",
   "years",
+  "yline",
   "ymd",
-  "ytickangle",
   "ytickformat",
   "yyaxis",
   "yyyymmdd",
-  "ztickangle",
   "ztickformat",
   };
 
   rlist = list;
+
 endfunction
 
+
 %!test
 %! str = __unimplemented__ ("no_name_function");
 %! assert (isempty (str));
+
+%!test
 %! str = __unimplemented__ ("matlabrc");
-%! assert (str(1:71), "matlabrc is not implemented.  Octave uses the file '.octaverc' instead.");
+%! assert (regexp (str, "matlabrc is not implemented\.  Octave uses the file .\.octaverc. instead\."));
+
+%!test
 %! str = __unimplemented__ ("MException");
-%! assert (str(1:58), "the 'MException' function is not yet implemented in Octave");
+%! assert (regexp (str, "The .MException. function is not yet implemented in Octave"));
