@@ -1,4 +1,9 @@
-## Copyright (C) 2004-2019 John W. Eaton
+########################################################################
+##
+## Copyright (C) 2004-2023 The Octave Project Developers
+##
+## See the file COPYRIGHT.md in the top-level directory of this
+## distribution or <https://octave.org/copyright/>.
 ##
 ## This file is part of Octave.
 ##
@@ -15,24 +20,20 @@
 ## You should have received a copy of the GNU General Public License
 ## along with Octave; see the file COPYING.  If not, see
 ## <https://www.gnu.org/licenses/>.
+##
+########################################################################
 
 ## -*- texinfo -*-
-## @deftypefn {} {} isunix ()
+## @deftypefn {} {@var{tf} =} isunix ()
 ## Return true if Octave is running on a Unix-like system and false otherwise.
 ## @seealso{ismac, ispc}
 ## @end deftypefn
 
-function retval = isunix ()
+function tf = isunix ()
 
-  if (nargin == 0)
-    retval = __octave_config_info__ ("unix");
-  else
-    print_usage ();
-  endif
+  tf = __octave_config_info__ ("unix");
 
 endfunction
 
 
 %!assert (islogical (isunix ()))
-
-%!error isunix (1)
